@@ -1,8 +1,10 @@
 from workos.audit_trail import AuditTrail
 from workos.directory_sync import DirectorySync
+from workos.organizations import Organizations
 from workos.passwordless import Passwordless
 from workos.portal import Portal
 from workos.sso import SSO
+from workos.webhooks import Webhooks
 
 
 class Client(object):
@@ -26,6 +28,12 @@ class Client(object):
             self._directory_sync = DirectorySync()
         return self._directory_sync
 
+    @property
+    def organizations(self):
+        if not getattr(self, "_organizations", None):
+            self._organizations = Organizations()
+        return self._organizations
+
     @property
     def passwordless(self):
         if not getattr(self, "_passwordless", None):
@@ -38,5 +46,11 @@ class Client(object):
             self._portal = Portal()
         return self._portal
 
+    @property
+    def webhooks(self):
+        if not getattr(self, "_webhooks", None):
+            self._webhooks = Webhooks()
+        return self._webhooks
+
 
 client = Client()
