@@ -111,12 +111,19 @@ class DirectorySync(object):
         )
 
     def list_directories(
-        self, domain=None, search=None, limit=RESPONSE_LIMIT, before=None, after=None
+        self,
+        domain=None,
+        search=None,
+        limit=RESPONSE_LIMIT,
+        before=None,
+        after=None,
+        organization=None,
     ):
         """Gets details for existing Directories.
 
         Args:
             domain (str): Domain of a Directory. (Optional)
+            organization: ID of an Organization (Optional)
             search (str): Searchable text for a Directory. (Optional)
             limit (int): Maximum number of records to return. (Optional)
             before (str): Pagination cursor to receive records before a provided Directory ID. (Optional)
@@ -127,6 +134,7 @@ class DirectorySync(object):
         """
         params = {
             "domain": domain,
+            "organization_id": organization,
             "search": search,
             "limit": limit,
             "before": before,
@@ -139,6 +147,21 @@ class DirectorySync(object):
             token=workos.api_key,
         )
 
+    def get_directory(self, directory_id):
+        """Gets details for a single Directory.
+
+        Args:
+            directory_id (str): Directory unique identifier.
+
+        Returns:
+            dict: Directory response from WorkOS.
+        """
+        return self.request_helper.request(
+            "directories/{directory_id}".format(directory_id=directory_id),
+            method=REQUEST_METHOD_GET,
+            token=workos.api_key,
+        )
+
     def delete_directory(self, directory):
         """Delete one existing Directory.
 
