@@ -39,7 +39,15 @@ class SSO(object):
         return self._request_helper
 
     def get_authorization_url(
-        self, domain=None, redirect_uri=None, state=None, provider=None, connection=None
+        self,
+        domain=None,
+        domain_hint=None,
+        login_hint=None,
+        redirect_uri=None,
+        state=None,
+        provider=None,
+        connection=None,
+        organization=None,
     ):
         """Generate an OAuth 2.0 authorization URL.
 
@@ -53,6 +61,7 @@ class SSO(object):
             back as a query parameter
             provider (ConnectionType) - Authentication service provider descriptor
             connection (string) - Unique identifier for a WorkOS Connection
+            organization (string) - Unique identifier for a WorkOS Organization
 
         Returns:
             str: URL to redirect a User to to begin the OAuth workflow with WorkOS
@@ -63,22 +72,40 @@ class SSO(object):
             "response_type": RESPONSE_TYPE_CODE,
         }
 
-        if domain is None and provider is None and connection is None:
+        if (
+            domain is None
+            and provider is None
+            and connection is None
+            and organization is None
+        ):
             raise ValueError(
-                "Incomplete arguments. Need to specify either a 'connection', 'domain' or 'provider'"
+                "Incomplete arguments. Need to specify either a 'connection', 'organization', 'domain', or 'provider'"
             )
         if provider is not None:
             if not isinstance(provider, ConnectionType):
                 raise ValueError("'provider' must be of type ConnectionType")
             params["provider"] = str(provider.value)
         if domain is not None:
+            warn(
+                "The 'domain' parameter for 'get_authorization_url' is deprecated. Please use 'organization' instead.",
+                DeprecationWarning,
+            )
             params["domain"] = domain
+        if domain_hint is not None:
+            params["domain_hint"] = domain_hint
+        if login_hint is not None:
+            params["login_hint"] = login_hint
         if connection is not None:
             params["connection"] = connection
+        if organization is not None:
+            params["organization"] = organization
 
         if state is not None:
             params["state"] = state
 
+        if redirect_uri is None:
+            raise ValueError("Incomplete arguments. Need to specify a 'redirect_uri'.")
+
         prepared_request = Request(
             "GET",
             self.request_helper.generate_api_url(AUTHORIZATION_PATH),
@@ -167,8 +194,27 @@ class SSO(object):
         Returns:
             dict: Connections response from WorkOS.
         """
+
+        # This method used to accept `connection_type` as a string, so we try
+        # to convert strings to a `ConnectionType` to support existing callers.
+        #
+        # TODO: Remove support for string values of `ConnectionType` in the next
+        #       major version.
+        if connection_type is not None and isinstance(connection_type, str):
+            try:
+                connection_type = ConnectionType[connection_type]
+
+                warn(
+                    "Passing a string value as the 'connection_type' parameter for 'list_connections' is deprecated and will be removed in the next major version. Please pass a 'ConnectionType' instead.",
+                    DeprecationWarning,
+                )
+            except KeyError:
+                raise ValueError("'connection_type' must be a member of ConnectionType")
+
         params = {
-            "connection_type": connection_type,
+            "connection_type": (
+                connection_type.value if connection_type is not None else None
+            ),
             "domain": domain,
             "organization_id": organization_id,
             "limit": limit,
